//
//  RideNavController.m
//  NaviKitDemo
//
//  Created by mol on 2022/10/27.
//

#import "RideNavController.h"

#import <TencentNavKit/TencentNavKit.h>
#import <TNKAudioPlayer/TNKAudioPlayer.h>

@interface RideNavController ()  <TNKRideNavDelegate, TNKRideNavViewDelegate>

@property (nonatomic, strong) TNKRideNavManager *naviManager;
@property (nonatomic, strong) TNKRideNavView *naviView;

@property (nonatomic, strong) TencentLBSLocation *latestLocation;
@end
@implementation RideNavController

- (void)dealloc {
    [self.naviManager unregisterAllNavDelegates];
    [self.naviManager stopNav];
}

- (void)viewDidLoad {
    [super viewDidLoad];
    // Do any additional setup after loading the view.
    self.naviManager = [TNKRideNavManager sharedInstance];
    self.naviManager.locationSimulator.simulationSpeed = 20;
    self.naviManager.audioPlayer = [TNKAudioPlayer sharedAudioPlayer];
    self.naviView = [[TNKRideNavView alloc] initWithFrame:self.view.bounds];
    self.naviView.showUIElements = YES;
    self.naviView.delegate = self;
    [self.naviView updateRedLineConfig:[[TNKRedLineConfig alloc] init]];
    [self.view addSubview:self.naviView];
    
    [self.naviManager registerNavDelegate:self.naviView];
    [self.naviManager registerNavDelegate:self];

    [self planningRoute];
}

#pragma mark - private

- (void)planningRoute {
    
    TNKDriveRouteRequest *request = [[TNKDriveRouteRequest alloc] init];
    TNKSearchNavPoint *dest = [[TNKSearchNavPoint alloc] init];
    dest.coordinate = CLLocationCoordinate2DMake(39.970263, 116.424866);
    request.destination = dest;

    TNKSearchNavPoint *orig = [[TNKSearchNavPoint alloc] init];
    orig.coordinate = CLLocationCoordinate2DMake(39.978629, 116.424630);
    request.origin = orig;
    
    request.searchOption = [[TNKDriveRouteSearchOption alloc] init];

    __weak typeof(self) weakself = self;
    [self.naviManager searchRoutesWithRequest:request completion:^(TNKRideRouteSearchResult * _Nullable routesRsp,
                                                                   NSError * _Nullable error) {
        if (error != nil) {
            return;
        }
        
        weakself.naviManager.locationSimulator.enabled = YES;
        [weakself.naviManager startNavWithIndex:0];
        //        [weakself.naviManager startWithRouteID:routesRsp.routes.firstObject.routeID];
    }];
}

#pragma mark - TNKRideNavDelegate

- (void)rideNavManagerDidStart:(TNKRideNavManager *)manager {
    
}

- (void)rideNavManagerDidStop:(TNKRideNavManager *)manager {
    
}

- (void)rideNavManager:(TNKRideNavManager *)manager didStartRerouting:(TNKRerouteReason)rerouteReason {
    
}

- (void)rideNavManager:(TNKRideNavManager *)manager updateNavigationData:(TNKRideNavigationData *)navigationData {
    
}

- (void)rideNavManager:(TNKRideNavManager *)manager didUpdateLocation:(TNKLocation *)location {
    
}

#pragma mark - TNKRideNavViewDelegate

- (void)navViewCloseButtonClicked:(TNKBaseNavView *)navView {
    [self.naviManager stopNav];
    [self.naviView clearAllRouteUI];
}
@end
